summaryrefslogtreecommitdiff
path: root/gtk2_ardour/rgb_macros.h
diff options
context:
space:
mode:
authorTaybin Rutkin <taybin@taybin.com>2005-09-25 22:26:56 +0000
committerTaybin Rutkin <taybin@taybin.com>2005-09-25 22:26:56 +0000
commit14d43ca9fe28a8309b4a52fa85e2b0c64a92248b (patch)
tree0ca37421248da4aaba70869fbc0156bf64e3b0ce /gtk2_ardour/rgb_macros.h
parentd38e2213d79b1c8952c776a3b60f7709457edc0c (diff)
Switched to use libgnomecanvas (not the C++ one).
git-svn-id: svn://localhost/trunk/ardour2@30 d708f5d6-7413-0410-9779-e7cbd77b26cf
Diffstat (limited to 'gtk2_ardour/rgb_macros.h')
-rw-r--r--gtk2_ardour/rgb_macros.h18
1 files changed, 9 insertions, 9 deletions
diff --git a/gtk2_ardour/rgb_macros.h b/gtk2_ardour/rgb_macros.h
index f0a67ec0bd..310e0a224d 100644
--- a/gtk2_ardour/rgb_macros.h
+++ b/gtk2_ardour/rgb_macros.h
@@ -125,7 +125,7 @@ UINT_TO_RGB((i), ((guchar*)p), ((guchar*)p)+1, ((guchar*)p)+2)
}
#define PAINT_HORIZ(inbuf, colr, colg, colb, ptx0, ptx1, pty) \
{ \
- GtkCanvasBuf* ph_buf = (inbuf); \
+ GnomeCanvasBuf* ph_buf = (inbuf); \
guchar* ph_p; \
gint ph_a0, ph_a1; \
gint ph_colr=(colr), ph_colg=(colg), ph_colb=(colb); \
@@ -144,7 +144,7 @@ UINT_TO_RGB((i), ((guchar*)p), ((guchar*)p)+1, ((guchar*)p)+2)
}
#define FAST_PAINT_HORIZ(inbuf, colr, colg, colb, ptx0, ptx1, pty) \
{ \
- GtkCanvasBuf* ph_buf = (inbuf); \
+ GnomeCanvasBuf* ph_buf = (inbuf); \
guchar* ph_p; \
gint ph_a0, ph_a1; \
gint ph_colr=(colr), ph_colg=(colg), ph_colb=(colb); \
@@ -163,7 +163,7 @@ UINT_TO_RGB((i), ((guchar*)p), ((guchar*)p)+1, ((guchar*)p)+2)
}
#define PAINT_HORIZA(inbuf, colr, colg, colb, cola, ptx0, ptx1, pty) \
{ \
- GtkCanvasBuf* ph_buf = (inbuf); \
+ GnomeCanvasBuf* ph_buf = (inbuf); \
guchar* ph_p; \
gint ph_a0, ph_a1; \
gint ph_colr=(colr), ph_colg=(colg), ph_colb=(colb), ph_cola=(cola); \
@@ -182,7 +182,7 @@ UINT_TO_RGB((i), ((guchar*)p), ((guchar*)p)+1, ((guchar*)p)+2)
}
#define PAINT_VERT(inbuf, colr, colg, colb, ptx, pty0, pty1) \
{ \
- GtkCanvasBuf* pv_buf = (inbuf); \
+ GnomeCanvasBuf* pv_buf = (inbuf); \
guchar* pv_p; \
gint pv_b0, pv_b1; \
gint pv_colr=(colr), pv_colg=(colg), pv_colb=(colb);\
@@ -201,7 +201,7 @@ UINT_TO_RGB((i), ((guchar*)p), ((guchar*)p)+1, ((guchar*)p)+2)
}
#define FAST_PAINT_VERT(inbuf, colr, colg, colb, ptx, pty0, pty1) \
{ \
- GtkCanvasBuf* fpv_buf = (inbuf); \
+ GnomeCanvasBuf* fpv_buf = (inbuf); \
guchar* fpv_p; \
gint fpv_b0, fpv_b1; \
\
@@ -218,7 +218,7 @@ UINT_TO_RGB((i), ((guchar*)p), ((guchar*)p)+1, ((guchar*)p)+2)
}
#define PAINT_VERTA(inbuf, colr, colg, colb, cola, ptx, pty0, pty1) \
{ \
- GtkCanvasBuf* pv_buf = (inbuf); \
+ GnomeCanvasBuf* pv_buf = (inbuf); \
guchar* pv_p; \
gint pv_b0, pv_b1; \
gint pv_colr=(colr), pv_colg=(colg), pv_colb=(colb), pv_cola=(cola);\
@@ -236,12 +236,12 @@ UINT_TO_RGB((i), ((guchar*)p), ((guchar*)p)+1, ((guchar*)p)+2)
} \
}
/* Paint a solid-colored box into a GtkCanvasBuf (clipping as necessary).
The box contains (ptx0,pty0), but not (ptx1, pty1).
Each macro arg should appear exactly once in the body of the code. */
#define PAINT_BOX(inbuf, colr, colg, colb, cola, ptx0, pty0, ptx1, pty1) \
{ \
- GtkCanvasBuf* pb_buf = (inbuf); \
+ GnomeCanvasBuf* pb_buf = (inbuf); \
guchar* pb_p; \
guchar* pb_pp; \
gint pb_a0, pb_a1, pb_b0, pb_b1, pb_i, pb_j; \
@@ -269,7 +269,7 @@ UINT_TO_RGB((i), ((guchar*)p), ((guchar*)p)+1, ((guchar*)p)+2)
#define FAST_PAINT_BOX(inbuf, colr, colg, colb, cola, ptx0, pty0, ptx1, pty1) \
{ \
- GtkCanvasBuf* pb_buf = (inbuf); \
+ GnomeCanvasBuf* pb_buf = (inbuf); \
guchar* pb_p; \
guchar* pb_pp; \
gint pb_i, pb_j; \
@@ -236,12 +236,12 @@ UINT_TO_RGB((i), ((guchar*)p), ((guchar*)p)+1, ((guchar*)p)+2)
} \
}
-/* Paint a solid-colored box into a GtkCanvasBuf (clipping as necessary).
+/* Paint a solid-colored box into a GnomeCanvasBuf (clipping as necessary).
The box contains (ptx0,pty0), but not (ptx1, pty1).
Each macro arg should appear exactly once in the body of the code. */